@@ -18,7 +18,7 @@
  *    Boston, MA 02111-1307, USA.
  */
 
-/* $Id: ps_util.c,v 1.45 2008/01/04 07:39:31 steinm Exp $ */
+/* $Id$ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -637,9 +637,9 @@ FILE *ps_open_file_in_path(PSDoc *psdoc, const char *filename) {
 #else
 			sprintf(buffer, "%s/%s", pathres[i]->value, filename);
 #endif
-			fprintf(stderr, "Searching for %s\n", buffer);
+//			fprintf(stderr, "Searching for %s\n", buffer);
 			if(fp = fopen(buffer, "rb")) {
-				fprintf(stderr, "found %s in %s\n", filename, pathres[i]->value);
+//				fprintf(stderr, "found %s in %s\n", filename, pathres[i]->value);
 				break;
 			}
 		}
